@@ -7,5 +7,9 @@ use Attribute::Abstract;
 
 sub get_type : Abstract;
 
+sub cast: Abstract;
+
+sub get_enum_item : Abstract;
+
 no Moose;
 1;
\ No newline at end of file
